package com.ruoyi.bst.customer.domain;

import java.time.LocalDateTime;
import java.util.List;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import org.springframework.format.annotation.DateTimeFormat;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.system.valid.DictValid;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 客户对象 bst_customer
 *
 * @author ruoyi
 * @date 2025-01-22
 */
@Data
public class Customer extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    private Long id;

    @Excel(name = "客户编号")
    @ApiModelProperty("客户编号")
    @NotBlank(message = "客户编号不能为空", groups = {ValidGroup.Create.class})
    @Size(max = 32, message = "客户编号长度不能超过32个字符")
    private String code;

    @Excel(name = "客户姓名")
    @ApiModelProperty("客户姓名")
    @NotBlank(message = "客户姓名不能为空", groups = {ValidGroup.Create.class})
    @Size(max = 50, message = "客户姓名长度不能超过50个字符")
    private String name;

    @Excel(name = "状态", readConverterExp = "1=潜在,2=意向,3=成交,4=失效")
    @ApiModelProperty("状态")
    @NotBlank(message = "状态不能为空", groups = {ValidGroup.Create.class})
    @DictValid(type = DictType.CUSTOMER_STATUS, message = "非法的状态值")
    private String status;

    @Excel(name = "意向强度", readConverterExp = "1=高,2=中,3=低")
    @ApiModelProperty("意向强度")
    @NotBlank(message = "意向强度不能为空", groups = {ValidGroup.Create.class})
    @DictValid(type = DictType.CUSTOMER_INTENT_LEVEL, message = "非法的意向强度值")
    private String intentLevel;

    @Excel(name = "手机号")
    @ApiModelProperty("手机号")
    @Size(max = 11, message = "手机号长度不能超过11个字符")
    private String mobile;

    @Excel(name = "微信号")
    @ApiModelProperty("微信号")
    @Size(max = 50, message = "微信号长度不能超过50个字符")
    private String wechat;

    @Excel(name = "来源")
    @ApiModelProperty("来源")
    @Size(max = 100, message = "来源长度不能超过100个字符")
    @NotBlank(message = "来源不能为空", groups = {ValidGroup.Create.class})
    private String source;

    @Excel(name = "意向")
    @ApiModelProperty("意向")
    @Size(max = 30, message = "意向数量不能超过30个")
    private List<String> intents;

    @Excel(name = "跟进人ID")
    @ApiModelProperty("跟进人ID")
    @NotNull(message = "跟进人ID不能为空", groups = {ValidGroup.Create.class})
    private Long followId;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "最近跟进时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("最近跟进时间")
    private LocalDateTime lastFollowTime;

}
